summaryrefslogtreecommitdiff
path: root/src/include/taler_merchant_testing_lib.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_merchant_testing_lib.h')
-rw-r--r--src/include/taler_merchant_testing_lib.h13
1 files changed, 12 insertions, 1 deletions
diff --git a/src/include/taler_merchant_testing_lib.h b/src/include/taler_merchant_testing_lib.h
index c860baf2..372dd6ee 100644
--- a/src/include/taler_merchant_testing_lib.h
+++ b/src/include/taler_merchant_testing_lib.h
@@ -1782,7 +1782,7 @@ TALER_TESTING_cmd_merchant_delete_webhook (const char *label,
unsigned int http_status);
/**
* to use the 'taler-merchant-webhook' program.
*
* @param label command label.
* @param config_filename configuration file used by the webhook.
@@ -1793,6 +1793,17 @@ TALER_TESTING_cmd_webhook (const char *label,
/**
+ * Command to run the 'taler-merchant-exchange' program.
+ *
+ * @param label command label.
+ * @param config_filename configuration file used by the webhook.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_run_tme (const char *label,
+ const char *config_filename);
+
+
+/**
* This function is used to start the web server.
*
* @param label command label
@@ -1782,7 +1782,7 @@ TALER_TESTING_cmd_merchant_delete_webhook (const char *label,
unsigned int http_status);
/**
- * to use the 'taler-merchant-webhook' program.
+ * Command to run the 'taler-merchant-webhook' program.
*
* @param label command label.